@@ -23,7 +23,6 @@ from itertools import repeat, starmap
 
 def _find_mates(spp, sex=False, repro_age=None, choose_nearest=False,
                 inverse_dist_mating=False):
-    mating_radius = spp.mating_radius
     # NOTE: In an IDEAL world, this would work as follows:
     # for all individuals, find set of nearest neighbors (excluding selves)
     # for females:
@@ -34,8 +33,7 @@ def _find_mates(spp, sex=False, repro_age=None, choose_nearest=False,
     ######################################################
     # First, query the scipy.spatial.cKDTree (i.e. spp._kd_tree) for
     #nearest-neigh pairs
-    pairs = spp._get_mating_pairs(dist=mating_radius,
-                                  choose_nearest=choose_nearest,
+    pairs = spp._get_mating_pairs(choose_nearest=choose_nearest,
                                   inverse_dist_mating=inverse_dist_mating)
     ####################################################
     # Then, operationalize sexes, if being used, and find all 
@@ -58,7 +56,13 @@ def _find_mates(spp, sex=False, repro_age=None, choose_nearest=False,
     else:
         # delete inverse-equal pairs from list (i.e. if 3-paired-to-5 and 
         #5-paired-to-3 are both listed, drop one)
-        mating_pairs = np.array(list(map(tuple, set(map(frozenset, pairs)))))
+        # NOTE: only if mating_radius is not None, because if it is None then
+        #       WF-style panmixia should be enforced, in which case we should
+        #       allow for draws with replacement to generate duplicate pairs
+        if spp.mating_radius is not None:
+            mating_pairs = np.array(list(map(tuple, set(map(frozenset, pairs)))))
+        else:
+            mating_pairs = pairs
     ##############################################
     # Check if any available pairs have been found thus far, proceed if so,
     #otherwise return empty array of pairs
@@ -122,23 +126,29 @@ def _draw_n_births(num_pairs, n_births_distr_lambda):
     return num_births
 
 
-# function for mating a chosen mating-pair
+# function for mating for a single offspring for a certain mating pair
 def _do_mating_sngl_offspr(spp, pair, recomb_keys):
     # choose a start homologue
     # NOTE: for now, this will only work for diploidy
     start_homologues = r.binomial(1, 0.5, 2)
-    # generate the segment info for each parent's new, recombined gamete
+
+    # if using tskit, generate the segment info for each parent's new,
+    # recombined gamete
     # NOTE: reverse the order of the recomb_paths object so that the resulting
     # segment info objects' order matches the order in which the recombination
     # paths are popped in the following line of code (because they will pop
     # off the right end of their list)
-    seg_info = [spp.gen_arch.recombinations._get_seg_info(
-                    start_homologue=start_homologues[i],
-                    event_key=k,
-                    node_ids=np.array([spp[pair[i]]._nodes_tab_ids[
+    if spp.gen_arch.use_tskit:
+        seg_info = [spp.gen_arch.recombinations._get_seg_info(
+                        start_homologue=start_homologues[i],
+                        event_key=k,
+                        node_ids=np.array([spp[pair[i]]._nodes_tab_ids[
                              homol] for homol in range(
                              spp.gen_arch.x)])
-                   ) for i, k in enumerate(recomb_keys)]
+                        ) for i, k in enumerate(recomb_keys)]
+    else:
+        seg_info = None
+
     # generate each parent's new, recombined gamete (and make into a new genome
     # by stacking and transposing)
     # NOTE: the first path winds up the left side of the new genome, thus
@@ -146,42 +156,59 @@ def _do_mating_sngl_offspr(spp, pair, recomb_keys):
     # `seg_info` list and the first (i.e. left) half of the new genome
     # both correspond to the genomic material inherited from the first of the
     # two parents whose ids are listed in `pair`
-    if len(spp.gen_arch.nonneut_loci) > 0:
+    if ((spp.gen_arch.use_tskit and len(spp.gen_arch.nonneut_loci) > 0)
+        or not spp.gen_arch.use_tskit):
         subsetters = [spp.gen_arch.recombinations._get_subsetter(
                                         event_key=k) for k in recomb_keys]
         #NOTE: flip the genome L-R before subsetting, if the start homologue is
         # 1, then flatten genome and subset
         new_genome = [np.fliplr(spp[ind].g).flatten(
-            )[[*sub]] if hom else spp[ind].g.flatten(
-            )[[*sub]] for ind, hom, sub in zip(pair, 
+            )[np.bool8([*sub])] if hom else spp[ind].g.flatten(
+            )[np.bool8([*sub])] for ind, hom, sub in zip(pair,
                                                start_homologues, subsetters)]
         new_genome = np.vstack(new_genome).T
     else:
         new_genome = None
-
     return new_genome, seg_info
 
 
-def _do_mating_sngl_pair(spp, pair, n_offspring, pairs_recomb_keys):
+# function for mating a chosen mating-pair
+def _do_mating_sngl_pair(spp, pair, n_births, pairs_recomb_keys):
     # generate a list of n offspring for the given pair
     offspring = [_do_mating_sngl_offspr(spp, pair,
                                         [pairs_recomb_keys.pop(
                                         ) for _ in range(2)]) for off in range(
-                                                                  n_offspring)]
+                                                                  n_births)]
     return offspring
 
 
-# function for mating a chosen mating-pair
-def _do_mating(spp, mating_pairs, n_offspring, recomb_keys):
+# function for mating a whole species
+def _do_mating(spp, mating_pairs, n_births, recomb_keys):
+    """
+    NOT INTENDED FOR PUBLIC USE
+
+    spp: a gnx Species object
+
+    mating_pairs: an nx2 2d np.array of ints, where n = number of mating pairs,
+                  2 columns correspond to each of the two mates in each pair,
+                  and each int is the index number of an Individual in a pair
+
+    n_births: a length-n 1d np.array of ints, where n = number of mating pairs
+              and each int is the number of offspring the nth pair will produce
+
+    recomb_keys: an m-length list of ints, where m = twice the
+                 total number of births and each int is a randomly drawn
+                 recombination event's key
+    """
     # use list of number of offspring per mating pair to create
     # list of start and stop indices for subsetting the recomb paths into
     # groups of paths to be used for each gamete-production event for each pair
-    start_stop_idxs = np.hstack((0, np.cumsum([2*n for n in n_offspring])))
+    start_stop_idxs = np.hstack((0, np.cumsum([2*n for n in n_births])))
     # get the recombination paths to be used by each pair
     pairs_recomb_keys = [recomb_keys[start_stop_idxs[i]: start_stop_idxs[
-                                    i + 1]] for i in range(len(n_offspring))]
+                                    i + 1]] for i in range(len(n_births))]
     # use the pairs' paths to produce recombinant genomes for each pair (where
     # number of genomes equals that pair's number of offspring)
     new_genomes = list(starmap(_do_mating_sngl_pair, zip(repeat(spp),
-                               mating_pairs, n_offspring, pairs_recomb_keys)))
+                               mating_pairs, n_births, pairs_recomb_keys)))
     return new_genomes
