@@ -157,6 +157,12 @@ class _DataCollector:
             and 'geo_rast_format' in format_params.keys()):
             self.rast_format = format_params.geo_rast_format
 
+        # grab the format for CSV files containing the non-neutral loci
+        # NOTE: None indicates that these files should not be produced
+        self.nonneut_loc_format = format_params.nonneut_loc_format
+        assert self.nonneut_loc_format in ['csv', None], ("the "
+            "'nonneut_loc_format' parameter must be either 'csv' or None.")
+
     #method to set self.next_t
     def _set_next_t(self):
         try:
@@ -256,6 +262,11 @@ class _DataCollector:
                         filepath = os.path.join(subdirname, filename)
                         self._write_gendata(filepath, '')
 
+                # write the non-neutral loci CSV file, if required,
+                # and if this is the final timestep
+                if self.nonneut_loc_format is not None:
+                    self._write_nonneut_loc_file(spp, subdirname, iteration)
+
             #write the raster, if necessary
             if self.rast_format is not None:
                 #for each Layer
@@ -305,7 +316,8 @@ class _DataCollector:
         elif self.scheme in ['point', 'transect']:
             inds = self._get_point_sample(spp)
             sample.update(inds)
-        #convert sample to a dict of individuals
+        #sort sample, then convert to a dict of individuals
+        sample = sorted([*sample])
         sample = {i:spp[i] for i in sample}
         return(sample)
 
@@ -315,7 +327,7 @@ class _DataCollector:
                             'fasta'
                             'vcf'
         '''
-        genotypes = spp._get_genotypes(individs=sample, as_dict=True)
+        genotypes = spp._get_genotypes(individs=[*sample], as_dict=True)
         if data_format == 'fasta':
             formatted_data = _format_fasta(sample, genotypes)
         elif data_format == 'vcf':
@@ -333,6 +345,38 @@ class _DataCollector:
         write_fn(filepath = filepath, individuals = sample)
 
 
+    def _write_nonneut_loc_file(self, spp, subdir, iteration,
+                                format='csv'):
+        """
+        NOTE: this is agnostic of the fact that the number of non-neutral
+              loci can grow throughout a simulation because of mutation.
+              the user would need to compare across nonneutral locus files,
+              and/or compare with the mutation log,
+              in order to determine when loci became non-neutral.
+        """
+        # get all the non-neutral loci for each trait
+        locs_dict = {trt.name:
+                     [*trt.loci] for trt in spp.gen_arch.traits.values()}
+        # make the number of rows even across columns
+        max_nrow = np.max([len(v) for v in locs_dict.values()])
+        for k,v in locs_dict.items():
+            if len(v) < max_nrow:
+                locs_dict[k] = np.array([*v] + [np.nan]*(max_nrow-len(v)))
+        # recast as a DataFrame
+        locs_df = pd.DataFrame.from_dict(locs_dict)
+        # make the filename and filepath
+        filename = 'mod-%s_it-%i_t-%i_spp-%s_NONNEUTS.%s' % (self.model_name,
+                                                             iteration,
+                                                             self.next_t,
+                                                             spp.name,
+                                                             format)
+        filepath = os.path.join(subdir, filename)
+        # write the file, with trait names as column names
+        # and locus numbers down the non-fixed-length columns
+        locs_df.to_csv(filepath, index=False)
+
+
+
 ######################################
 # -----------------------------------#
 # FUNCTIONS -------------------------#
@@ -354,6 +398,29 @@ def _make_point_buffers(points, radius):
     return(cu)
 
 
+# a function that returns an ad hoc sample of size n
+# from the current population of the given spp,
+# in the format index-keyed dict format needed by the data-writing functions
+# (to be used by the convenience methods of the Model object)
+def _get_adhoc_sample(spp, n):
+    #get a set of indices for the individuals in the sample
+    sample = set()
+    #take the whole species, if scheme is 'all'
+    if n is None:
+        sample.update([*spp])
+    #or take a random sample, if scheme is 'random'
+    else:
+        if len(spp) > n:
+            inds = r.choice([*spp], size = n, replace = False)
+        else:
+            inds = [*spp]
+        sample.update(inds)
+    #sort sample, then convert to a dict of individuals
+    sample = sorted([*sample])
+    sample = {i:spp[i] for i in sample}
+    return(sample)
+
+
 def _format_fasta(sample, genotypes):
     '''
     FASTA FORMAT:
@@ -363,6 +430,12 @@ def _format_fasta(sample, genotypes):
     001110101010101010010101011101010110.....01011110
 
     '''
+    # ensure that sample and genotypes have identical lenghts and orders
+    assert len(sample) == len(genotypes), ("'sample', and 'genotypes' have"
+                                           "different lenghts!")
+    assert np.all([*sample] == [*genotypes]), ("'sample' and 'genotypes' do not"
+                                               " have identical orders!")
+
     row1 = '>%s:HAP;%s;%s;%s;%s;%s;%s\n'
     file_text = ''
 
@@ -383,6 +456,12 @@ def _format_fasta(sample, genotypes):
 
 def _format_vcf(sample, genotypes, gen_arch, include_fixed_sites=False):
 
+    # ensure that sample and genotypes have identical lenghts and orders
+    assert len(sample) == len(genotypes), ("'sample', and 'genotypes' have"
+                                           "different lenghts!")
+    assert np.all([*sample] == [*genotypes]), ("'sample' and 'genotypes' do not"
+                                               " have identical orders!")
+
     #create a template header
         #NOTE: has 1 string slot for a date
 
@@ -411,7 +490,7 @@ def _format_vcf(sample, genotypes, gen_arch, include_fixed_sites=False):
             #- a tab-separated list of individs' genotypes at this locus
 
     #create a col_header_row for this data
-    inds = sorted(sample.keys())
+    inds = [*sample.keys()]
     ind_cols = '\t'.join([str(i) for i in inds])
     cols = col_header_row % (ind_cols)
 
@@ -460,3 +539,25 @@ def _format_vcf(sample, genotypes, gen_arch, include_fixed_sites=False):
 
     #return it
     return(out_vcf)
+
+
+def _tskit_table_to_pandas(table):
+    """
+    Takes a raw tskit.TableCollection table dict,
+    as returned from tskit.TableCollection.<TABLENAME>.asdict(),
+    and converts it into a pandas.DataFrame, for write-out
+    """
+    # get the max column length
+    max_col_len = max([len(col) for col in table.values()])
+    # fill in columns with np.nan
+    filled_table = {}
+    for k, col in table.items():
+        if len(col) > 0:
+            filled_table[k] = np.concatenate((col,
+                                    np.nan * np.ones(max_col_len - len(col)))) 
+        else:
+            filled_table[k] = np.ones(max_col_len) * np.nan
+    # convert to pandas.DataFrame
+    pd_table = pd.DataFrame.from_dict(filled_table)
+    return pd_table
+
