@@ -42,8 +42,13 @@ class MutationRateError(Exception):
 
 
 class Recombinations:
+    """
+    Container for the parameters and data necessary to simulate recombination.
+
+    Not intended for public use.
+    """
     def __init__(self, L, positions, n, r_distr_alpha, r_distr_beta,
-                 recomb_rates):
+                 recomb_rates, jitter_breakpoints):
         # define the bitarray unit corresponding to each homologue
         self._bitarray_dict= {0: '10', 1: '01'}
 
@@ -69,6 +74,10 @@ class Recombinations:
         # recombination rates can be drawn
         self._r_distr_alpha = r_distr_alpha
         self._r_distr_beta = r_distr_beta
+        # flag indicating whether or not breakpoint locations should be
+        # jittered slightly off of their x.5 defaults, so that
+        # tskit.TreeSequence will correctly track and report the number of trees
+        self._jitter_breakpoints = jitter_breakpoints
         # get the recombination rates
         if recomb_rates is not None:
             assert len(recomb_rates) == len(positions), ("Lengths of provided "
@@ -86,19 +95,32 @@ class Recombinations:
         else:
             self._rates = self._draw_recombination_rates()
 
-    def _set_events(self, use_subsetters, nonneutral_loci):
-        # set the potential recombination breakpoints, their recombination
+    def _set_events(self, use_subsetters, nonneutral_loci, use_tskit):
+        # get the potential recombination breakpoints, their recombination
         # rates, and the cache of simulated recombination events to be used
         # by the model
-        (self._breakpoints,
-         self._subsetters) = self._draw_recombination_events(
-                use_subsetters=use_subsetters, nonneutral_loci=nonneutral_loci)
-        self._set_seg_info()
+        # NOTE: each item will only be generated and stored if it is needed,
+        #       depending on whether or not tskit is being used and, if it is
+        #       being used, whether or not there are non-neutral loci whose
+        #       genotypes need to be tracked
+        breakpoints, subsetters = self._draw_recombination_events(
+                                            use_subsetters=use_subsetters,
+                                            nonneutral_loci=nonneutral_loci,
+                                            use_tskit=use_tskit)
+        # if using tskit, set seg_info and use the breakpoints dict
+        if use_tskit:
+            self._breakpoints = breakpoints
+            self._set_seg_info()
+        # otherwise don't set seg_info and make the breakpoints dict None
+        else:
+            self._breakpoints = None
+        # either way, set the subsetters
+        self._subsetters = subsetters
 
     def _get_events(self, size):
         events = random.sample(self._events, size)
         return events
-     
+
     def _get_subsetter(self, event_key):
         return self._subsetters[event_key]
 
@@ -157,10 +179,11 @@ class Recombinations:
         # will actually be 1)
         recomb_rates[0] = 0
         return recomb_rates
-    
-    
+
+
     # simulate recombination events
-    def _draw_recombination_events(self, use_subsetters, nonneutral_loci):
+    def _draw_recombination_events(self, use_subsetters, nonneutral_loci,
+                                   use_tskit):
         """
         NOTE: Positions and recomb_rates must be provided already sorted!
         """
@@ -168,20 +191,29 @@ class Recombinations:
         recombinations = [r.binomial(1, self._rates) for _ in range(self._n)]
         breakpoints = [self._positions[np.where(
                                         recomb)] for recomb in recombinations]
+        for bp in breakpoints:
+            if len(bp) > 0:
+                assert 0 not in bp, '%s' % str(bp)
         # recast it as an int-keyed dict, so that when I use the recombination
         # events to simulate recombination I don't have to pass around the long
         # arrays, but instead can just random keys to index them out on the fly
         breakpoints = dict(zip(range(len(breakpoints)), breakpoints))
-   
+
         if use_subsetters:
             # get the recombination paths used to make the bitarray subsetters
-            if len(nonneutral_loci) > 0:
+            if ((use_tskit and len(nonneutral_loci) > 0)
+                or not use_tskit):
                 recomb_paths = [np.cumsum(
                                     recomb) % 2 for recomb in recombinations]
-                # grab just the values at the nonneutral loci
+                # if using tskit, grab just the values at the nonneutral loci
                 # (because the subsetters will be used only for subsetting
                 # the non-neutral genotypes carried with the individuals)
-                paths = [path[nonneutral_loci] for path in recomb_paths]
+                if use_tskit:
+                    paths = [path[nonneutral_loci] for path in recomb_paths]
+                # otherwise, use all values
+                else:
+                    paths = [path for path in recomb_paths]
+
                 subsetters = [bitarray.bitarray(''.join([self._bitarray_dict[
                             step] for step in path])) for path in paths]
                 # recast as integer-indexed dict
@@ -194,18 +226,21 @@ class Recombinations:
             subsetters = None
         return (breakpoints, subsetters)
 
-    
+
     # calculate the left and right segment edges for each recombination event
     def _set_seg_info(self):
         seg_info = {}
+        ##@##
         for k, recomb in self._breakpoints.items():
-            # NOTE: adding 0.5 to all recombination breakpoints, to indicate
-            # that reocmbination 'actually' happens halfway between
+            # NOTE: subtracting 0.5 from all recombination breakpoints,
+            # to indicate that recombination 'actually' happens halfway between
             # a pair of loci, (i.e. it actually subsets Individuals'
             # genomes in that way) without having the hold all the 0.5's
             # in the Recombinations._events data struct (to save on memory)
-            left = np.array([0] + [*recomb + 0.5])
-            right = np.array([*recomb + 0.5] + [self._L])
+            left = np.array([0] + [*recomb - 0.5])
+            right = np.array([*recomb - 0.5] + [self._L])
+            assert np.all((right-left)>0), ("Some of the following breakpoints"
+                        " are invalid: :%s") % str([*zip(left, right)])
             seg_info[k] = (left, right)
         self._seg_info = seg_info
 
@@ -219,6 +254,24 @@ class Recombinations:
     def _get_seg_info(self, start_homologue, event_key,
                                     node_ids):
         left, right = self._seg_info[event_key]
+        # add small jitter to the numbers, so that recombination breakpoints
+        # are essentially not repeated, and this way tskit can correctly track
+        # the number of breakpoints and number of trees
+        if self._jitter_breakpoints:
+            left[1:] = left[1:] + np.random.uniform(0, 0.0001, len(left)-1)
+            #left, right = [np.clip(seg_bps + np.random.uniform(0, 0.0001,
+            #                                                   len(seg_bps)),
+            #                       0, self._L) for seg_bps in [left, right]]
+
+            # NOTE: must make sure that each set of seg_info
+            # always starts at 0 on the leftmost segment
+            # (and ends at gen_arch.L on the rightmost, but that will already
+            #  happen in the above code because we're only ever adding a
+            #  positive value to original rightmost value, which is gen_arch.L,
+            #  then clipping that value back down to gen_arch.L)
+            #left[0] = 0
+            right[:-1] = left[1:]
+
         homologue_nodes = node_ids[[(i + start_homologue) % 2 for i in range(
                                                                    len(left))]]
         seg_info = zip(homologue_nodes, left, right)
@@ -226,6 +279,92 @@ class Recombinations:
 
 
 class Trait:
+    """
+    Representation of a single trait and its parameterization.
+
+    Trait objects are collected in a serial integer-keyed dict,
+    one per trait that is parameterized for the corresponding Species,
+    which inheres to the Species' GenomicArchitecture object as the attribute
+    `GenomicArchitecture.traits`, from which individual Traits can be indexed
+    using their index-number keys (e.g. `GenomicArchitecture.traits[<idx>]`).
+
+    Attributes
+    ----------
+
+        NOTE: For more detail, see the documentation for the parameters
+              that correspond to many of the following attributes.
+
+        alpha:
+            A 1d numpy array containing the effect sizes of all loci subtending
+            this trait. The value at index i represents the effect size of the
+            locus at index i in the 'loci' attribute of this Trait.
+
+        alpha_distr_mu:
+            Mean of the normal (Gaussian) distribution
+            of effect sizes for this trait's loci.
+
+        alpha_distr_sigma:
+            Standard deviation of the normal (Gaussian) distribution
+            of effect sizes for this trait's loci.
+
+        gamma:
+            Curvature of the fitness function.
+
+        idx:
+            Index number of the trait (i.e. its key within the traits dict)
+
+        loci_idxs:
+            A 1d numpy array containing the index positions within an
+            Individual's genotypes array
+            (attribute 'g' of an Individual) that
+            correspond to the loci subtending this trait.
+            (This is designed such that an Individual's genotype
+            for the locus number stored at Trait.loci[i]
+            can be accessed by calling Individual.g[Trait.loci_idxs[i], :].)
+            This method of tracking allows Individuals' full genotypes to be
+            stored in tskit tables (if tskit is being used)
+            while they carry their non-neutral genotypes with them
+            (a computational optimization).
+            Set to None if tskit is not being used.
+
+        loci:
+            A numerically sorted 1d numpy array containing
+            the locus numbers of all loci subtending this trait.
+
+        lyr_num:
+            Index number of the Landscape layer to which this trait corresponds
+            (i.e. of the environmental variable that serves as the selective
+            force on this trait)
+
+        max_alpha_mag:
+            Maximum absolute value that can be drawn for a locus’
+            effect size (i.e. alpha). Effect sizes are clipped
+            to the closed interval [-max_alpha_mag, max_alpha_mag]
+            when the model is parameterized.
+
+        mu:
+            Mutation rate for this trait (expressed in mutations per locus per
+            timestep)
+
+        name:
+            The string name of the trait
+
+        n_loci:
+            Number of loci subtending this trait
+
+        phi:
+            Polygenic selection coefficient (i.e the selection coefficient
+            acting on the phenotypes, rather than the genotypes, of this Trait)
+
+        univ_adv:
+            Whether or not this trait will be treated as universally
+            advantageous. When False (the default behavior), individuals will
+            be fitter when their phenotypic values for this trait more closely
+            align with the local environmental value of the landscape layer
+            corresponding to this trait (i.e. selection will be spatially
+            varying). When False, phenotypes closer to 1 will be more
+            advantageous globally on the Landscape.
+    """
     def __init__(self, idx, name, phi, n_loci, mu, layer, alpha_distr_mu,
                  alpha_distr_sigma, max_alpha_mag, gamma, univ_adv):
         self.idx = idx
@@ -243,7 +382,7 @@ class Trait:
         self.univ_adv = univ_adv
 
         self.loci = np.int64([])
-        self.loc_idx = np.int64([])
+        self.loci_idxs = np.int64([])
         self.alpha = np.array([])
 
     def _get_phi(self, spp):
@@ -260,11 +399,16 @@ class Trait:
         # set the number of loci
         self.n_loci = self.loci.size
 
-    def _set_loc_idx(self, nonneut_loci):
-        # set an index of the loci's indices in the nonneut_loci object,
+    def _set_loci_idxs(self, nonneut_loci, use_tskit):
+        # if using tskit then only non-neutral loci will be stored in
+        # Individuals' genotype arrays,
+        # so set an index of the loci's indices in the nonneut_loci object,
         # to use when subsetting for the trait's genotypes
-        self.loc_idx = np.array([np.where(
+        if use_tskit:
+            self.loci_idxs = np.array([np.where(
                                 nonneut_loci == n)[0][0] for n in self.loci])
+        else:
+            self.loci_idxs = None
 
     def _add_locus(self, locus, alpha, idx):
         # get insertion index for the locus 
@@ -279,18 +423,116 @@ class Trait:
                                alpha,
                                self.alpha[insert_pt:]))
 
-        # insert in the loc_idx
+        # insert in the loci_idxs
         # NOTE: add 1 to all superseding locus indexes, to account for
         # locus newly inserted into genotype arrays
-        self.loc_idx = np.hstack((self.loc_idx[:insert_pt],
+        self.loci_idxs = np.hstack((self.loci_idxs[:insert_pt],
                                   idx,
-                                  self.loc_idx[insert_pt:] + 1))
+                                  self.loci_idxs[insert_pt:] + 1))
 
         # increment the number of loci
         self.n_loci += 1
 
 
 class GenomicArchitecture:
+    """
+    Representation of the genomic architecture of a Species.
+
+    Inheres to its Species as the Species.gen_arch attribute.
+
+    Attributes
+    ----------
+
+        NOTE: For more detail, see the documentation for the parameters
+              that correspond to many of the following attributes.
+
+        delet_alpha_distr_scale:
+            The scale parameter of the Gamma distribution from which
+            the effect sizes (i.e. alphas) of deleterious loci are drawn
+
+        delet_alpha_distr_shape:
+            The shape parameter of the Gamma distribution from which
+            the effect sizes (i.e. alphas) of deleterious loci are drawn
+
+        delet_loci:
+            A 1d numpy array that tracks all deleterious loci
+
+        delet_loci_idxs:
+            A 1d numpy array containing the index positions within an
+            Individual's genotypes array (attribute 'g' of an Individual)
+            that correspond to the deleterious loci.
+            (This is designed such that an Individual's genotype for
+            the deleterious locus number stored at
+            GenomicArchitecture.delet_loci[i] can be accessed by calling
+            Individual.g[GenomicArchitecture.delet_loci_idxs[i], :].)
+            This method of tracking allows Individuals' full genotypes to be
+            stored in the tskit tables (if tskit is being used)
+            while they carry their non-neutral genotypes with them
+            (a computational optimization).
+            Set to None if tskit is not being used.
+
+        delet_loci_s:
+            A 1d numpy array containing the selection strengths
+            of each of the deleterious loci. (Selection strengths are
+            listed in an order corresponding to the order of
+            GenomicArchitecture.delet_loci, such that the selection strength of
+            the deleterious locus referenced at
+            GenomicArchitecture.delet_loci[i] is stored at
+            GenomicArchitetcture.delet_loci_s[i].)
+
+        dom:
+            Dominance values for all loci (stored as an L-length,
+            1d numpy array in which 0 indicates a codominant locus
+            and 1 indicates a locus for which the '1' allele is dominant)
+
+        L:
+            Length of the simulated genome
+
+        mu_delet:
+            Genome-wide deleterious mutation rate (expressed in mutations
+            per locus per timestep). Deleterious mutations do not influence
+            trait phenotypes, but instead are univerally
+            deleterious (to an extent determined by their effect sizes).
+
+        mu_neut:
+            Genome-wide neutral mutation rate (expressed in mutations
+            per locus per timestep).
+
+        neut_loci:
+            A 1d numpy array that tracks all loci that do not influence the
+            phenotypes of any traits.
+
+        nonneut_loci:
+            A 1d numpy array that tracks all loci that either influence the
+            phenotype of at least one trait or are deleterious.
+
+        p:
+            Starting allele frequencies for all loci (stored as an L-length,
+            1d numpy array)
+
+        pleiotropy:
+            A bool indicating whether or not to allow pleiotropy (i.e. whether
+            or not to allow the same locus to subtend multiple traits)
+
+        recombinations:
+            The Recombinations object, which contains the parameters and data
+            necessary for simulation of recombination. Not intended for public
+            use at this time.
+
+        sex:
+            A bool indicating whether or not Individuals of this Species
+            will be assigned a sex (0 for female, 1 for male)
+
+        traits:
+            A dict containing all of a Species' Trait objects, keyed by serial
+            integers.
+
+        x:
+            Ploidy
+            NOTE: only diploidy is currently implemented, but this attribute
+                  serves as a placeholder for use in possible
+                  future generalization to arbitrary ploidy.)
+    """
     def __init__(self, dom, g_params, land, recomb_rates=None,
                  recomb_positions=None):
         # ploidy (NOTE: for now will be 2 by default; later could consider
@@ -311,6 +553,19 @@ class GenomicArchitecture:
         # whether or not to use sexes for this species
         self.sex = g_params.sex
 
+        # whether or not to use tskit to track this species' spatial pedigree
+        self.use_tskit = g_params.use_tskit
+        assert self.use_tskit in [True, False], (("'use_tskit' must be either "
+                                                  "True or False for each "
+                                                  "Species."))
+        # set interval for simplifying the tskit TableCollection
+        self.tskit_simp_interval = g_params.tskit_simp_interval
+        if self.use_tskit:
+            assert isinstance(self.tskit_simp_interval,
+                              int), (("If using tskit then the "
+                                      "'tskit_simp_interval' parameter must be "
+                                      " an integer."))
+
         # genome-wide neutral mutation rate
         self.mu_neut = g_params.mu_neut
         # array to keep track of all loci that don't influence the
@@ -329,7 +584,7 @@ class GenomicArchitecture:
         # arrays to track deleterious loci, their genotype indices, and their
         # strengths of selection
         self.delet_loci = np.int64([])
-        self.delet_loc_idx = np.int64([])
+        self.delet_loci_idxs = np.int64([])
         self.delet_loci_s = np.array([])
 
         # add a dict of Trait objects, if necessary
@@ -363,7 +618,8 @@ class GenomicArchitecture:
                                              g_params.n_recomb_sims,
                                              g_params.r_distr_alpha,
                                              g_params.r_distr_beta,
-                                             recomb_rates)
+                                             recomb_rates,
+                                             g_params.jitter_breakpoints)
 
     # method to make a _mut_fns dict, containing a function
     # for each type of mutation for this species
@@ -508,6 +764,8 @@ class GenomicArchitecture:
                 self.traits[n]._add_locus(locus, alpha, idx)
         # or else add to the deleterious loci
         elif delet_s is not None and trait_nums is None:
+            # TODO: DECIDE IF NEED TO USE self.loci INSTEAD OF self.delet_loci
+            #       HERE IF use_tskit==False
             del_idx = bisect.bisect_left(self.delet_loci, locus)
             # add the locus, its genome-index (for subsetting individuals'
             # genomes when calculating fitness), and its strength of selection
@@ -515,17 +773,15 @@ class GenomicArchitecture:
             self.delet_loci = np.hstack((self.delet_loci[:del_idx],
                                          locus,
                                          self.delet_loci[del_idx:]))
-            self.delet_loc_idx = np.hstack((self.delet_loc_idx[:del_idx],
-                                         idx,
-                                         self.delet_loc_idx[del_idx:]))
+            if self.use_tskit:
+                self.delet_loci_idxs = np.hstack(
+                    (self.delet_loci_idxs[:del_idx], idx,
+                     self.delet_loci_idxs[del_idx:]))
+            else:
+                self.delet_loci_idxs = None
             self.delet_loci_s = np.hstack((self.delet_loci_s[:del_idx],
                                          delet_s,
                                          self.delet_loci_s[del_idx:]))
-
-        #TODO REMOVE NEXT 2 LINES AFTER TESTING
-        else:
-            assert True == False, "BOTH TRAITS_NUMS AND DELET_S CANT BE NONE!"
-
         return idx
 
 
@@ -646,14 +902,24 @@ def _make_genomic_architecture(spp_params, land):
 
     # get the custom recomb_rates and recomb_positions from the
     # custom gen-arch file, if provided
-    # NOTE: add 0.5 to each locus' position, because each recombination rate
-    #       stipulated in gen_arch file is construed as the recombination rate
-    #       at the midway point between that locus and the subsequent one
+    # NOTE: each recombination rate
+    #       stipulated in gen_arch file
+    #       is construed as the recombination rate
+    #       at the midway point between that locus
+    #       and the previous one
+    #       (NOTE: this is of course non-sensical for the 0th
+    #              locus, which would thus have its rate expressed as
+    #              the rate of recomb between the -1th and the 0th,
+    #              but that's fine because the first rate is later coerced to 0
+    #              anyhow, then the starting homologue of the recomb path,
+    #              i.e. the sister chromatid placed into the gamete,
+    #              is later chosen using a ~Bern(0.5) draw at the time
+    #              mating occurs; see mating.py)
     recomb_rates = None
     recomb_positions = None
     if gen_arch_file is not None:
-        recomb_rates = gen_arch_file['r'].values[:-1]
-        recomb_positions = gen_arch_file['locus'].values[:-1] + 0.5
+        recomb_rates = gen_arch_file['r'].values
+        recomb_positions = gen_arch_file['locus'].values# - 0.5
 
     # set locus-wise dominance values for the 1-alleles, using the 'dom' value
     # in the gen_arch params, unless a gen_arch_file was provided
@@ -670,8 +936,8 @@ def _make_genomic_architecture(spp_params, land):
                                    recomb_rates, recomb_positions)
 
     # set the loci and effect sizes for each trait, using the custom gen-arch
-    # file, if provided
-    if gen_arch_file is not None:
+    # file, if provided, and if the species has traits
+    if gen_arch_file is not None and gen_arch.traits is not None:
         # convert the trait names in the 'trait' column of the file into
         # lists of their trait numbers (i.e. their keys in the gen_arch
         # traits dict)
@@ -719,11 +985,12 @@ def _make_genomic_architecture(spp_params, land):
                 gen_arch._set_trait_loci(trait_num, mutational=False)
 
     # now that all nonneutral loci have been selected, 
-    # set each trait's loc_idx (which maps a trait's numeric loci to
+    # set each trait's loci_idxs (which maps a trait's numeric loci to
     # their index positions in individuals' genomes)
+    # NOTE: will just be set to None if not using tskit
     if gen_arch.traits is not None:
         for trt in gen_arch.traits.values():
-            trt._set_loc_idx(gen_arch.nonneut_loci)
+            trt._set_loci_idxs(gen_arch.nonneut_loci, gen_arch.use_tskit)
 
     assert_msg = ("The union of the gen_arch.neut_loci and "
                   "gen_arch.nonneut_loci sets does not contain all loci "
@@ -735,23 +1002,39 @@ def _make_genomic_architecture(spp_params, land):
     # draw locus-wise 1-allele frequencies, unless provided in
     # custom gen-arch file
     if gen_arch_file is None:
+        # set according to a non-None value
         if g_params.start_p_fixed is not None:
-            assert 0 <= g_params.start_p_fixed <= 1, ("If a starting allele "
-                                                      "frequency value is "
-                                                      "provided then it must "
-                                                      "be between 0 and 1.")
-            gen_arch.p = np.array([g_params.start_p_fixed]*g_params.L)
-            if g_params.start_neut_zero:
-                gen_arch.p[gen_arch.neut_loci] = 0
+            if isinstance(g_params.start_p_fixed, bool):
+                # if True, make all 0.5 (default starting allele freq)
+                if g_params.start_p_fixed:
+                    gen_arch.p = np.array([0.5]*g_params.L)
+                # if False, draw randomly
+                else:
+                    gen_arch.p = _draw_allele_freqs(g_params.L)
+            # if not a bool then should be a float, so assert,
+            # then set to that val
+            else:
+                assert 0 <= g_params.start_p_fixed <= 1, ("If a starting allele"
+                                                        " frequency value is "
+                                                        "provided then it must "
+                                                        "be between 0 and 1.")
+                gen_arch.p = np.array([g_params.start_p_fixed]*g_params.L)
+        # if the value is None, then draw randomly
         else:
             gen_arch.p = _draw_allele_freqs(g_params.L)
+        # set the neutral loci to 0, if need be
+        if g_params.start_neut_zero:
+            gen_arch.p[gen_arch.neut_loci] = 0
+    # use starting allele freq values from the gen_arch_file instead, if given
     else:
         gen_arch.p = gen_arch_file['p'].values
 
     # set the recombination events
-    use_subsetters = (len(gen_arch.nonneut_loci) > 0 or
-                      gen_arch._mu_nonneut > 0)
-    gen_arch.recombinations._set_events(use_subsetters, gen_arch.nonneut_loci)
+    use_subsetters = ((gen_arch.use_tskit and (len(gen_arch.nonneut_loci) > 0 or
+                                               gen_arch._mu_nonneut > 0))
+                      or not gen_arch.use_tskit)
+    gen_arch.recombinations._set_events(use_subsetters, gen_arch.nonneut_loci,
+                                        gen_arch.use_tskit)
 
     return gen_arch
 
@@ -823,16 +1106,23 @@ def _make_starting_mutations(spp, tables):
         np.random.shuffle(homologues)
         homologues_to_mutate = homologues[:n_mutations]
         for ind, homol in homologues_to_mutate:
-            # create a mutation in the individual's genome, if this is a
-            # non-neutral locus
-            if site in spp.gen_arch.nonneut_loci:
-                spp[ind].g[np.where(spp.gen_arch.nonneut_loci == site),
-                           homol] = 1
-            # get the homologue's nodes-table id,
-            # then add a row to the mutations table
-            node_id = spp[ind]._nodes_tab_ids[homol]
-            tables.mutations.add_row(site, node=node_id, parent=-1,
-                                     derived_state='1')
+            # if using tskit, add muts to individis' genotype arrays as needed,
+            # and also to mutations table
+            if spp.gen_arch.use_tskit:
+                # create a mutation in the individual's genome, if this is a
+                # non-neutral locus
+                if site in spp.gen_arch.nonneut_loci:
+                    spp[ind].g[np.where(spp.gen_arch.nonneut_loci == site),
+                               homol] = 1
+                # get the homologue's nodes-table id,
+                # then add a row to the mutations table
+                node_id = spp[ind]._nodes_tab_ids[homol]
+                tables.mutations.add_row(site, node=node_id, parent=-1,
+                                         derived_state='1')
+
+            # if not using tskit just add all muts to individs' genotypes arrays
+            else:
+                spp[ind].g[site, homol] = 1
 
     # and then reset the individuals' phenotypes, if needed
     if spp.gen_arch.traits is not None:
@@ -1041,7 +1331,8 @@ def _calc_lineage_direction(lin_dict):
         # convert to all positive values, 0 - 360
         if ang < 0:
             ang += 360
-        #convert to all positive clockwise angles, expressed as 0 at compass north
+        #convert to all positive clockwise angles,
+        # expressed as 0 at compass north
         # (i.e. angles clockwise from vector (X,Y) = (0,1)
         ang = (-ang + 90) % 360
         return ang
